@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011, 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@ import argparse
 import sys
 
 from .. import hocr
+from .. import text_zones
 from .. import version
 
 __version__ = version.__version__
@@ -47,7 +48,7 @@ class ArgumentParser(argparse.ArgumentParser):
     def parse_args(self, args=None, namespace=None):
         options = argparse.ArgumentParser.parse_args(self, args, namespace)
         if options.rotation % 90 != 0:
-            self.error('Rotation is not a multiple of 90 degrees')
+            self.error('rotation must be a multiple of 90 degrees')
         options.details = self._details_map[options.details]
         options.uax29 = options.language if options.word_segmentation == 'uax29' else None
         del options.word_segmentation
@@ -69,8 +70,8 @@ def get_texts(options):
 def main(argv=sys.argv):
     options = ArgumentParser().parse_args(argv[1:])
     for i, text in enumerate(get_texts(options)):
-        sys.stdout.write('select %d\nremove-txt\nset-txt\n' % (i + 1))
-        text.print_into(sys.stdout, 80)
+        sys.stdout.write('select {0}\nremove-txt\nset-txt\n'.format(i + 1))
+        text_zones.print_sexpr(text, sys.stdout, width=80)
         sys.stdout.write('\n.\n\n')
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
