@@ -273,20 +273,30 @@ class ArgumentParser(argparse.ArgumentParser):
             saver = None
         if saver is None:
             self.error(
-                'You must use exactly one of the following options: %s' %
-                ', '.join('/'.join(saver.options) for saver in self.savers)
+                'exactly one of the following options is required: {opt}'.format(
+                    opt=', '.join('/'.join(saver.options) for saver in self.savers)
+                )
             )
         if options.save_raw_ocr_dir is not None:
             try:
                 os.stat(os.path.join(options.save_raw_ocr_dir, ''))
             except EnvironmentError as ex:
-                self.error('cannot open %r: %s' % (ex.filename, ex[1]))
+                self.error('cannot open {path!r}: {msg}'.format(
+                    path=ex.filename,
+                    msg=ex[1],
+                ))
             try:
                 expand_template(options.raw_ocr_filename_template, pageno=0, pageid='')
             except ValueError as ex:
-                self.error('cannot parse filename template %r: %s' % (options.raw_ocr_filename_template, ex))
+                self.error('cannot parse filename template {tmpl!r}: {msg}'.format(
+                    tmpl=options.raw_ocr_filename_template,
+                    msg=ex,
+                ))
             except KeyError as ex:
-                self.error('cannot parse filename template %r: unknown field %r' % (options.raw_ocr_filename_template, ex.args[0]))
+                self.error('cannot parse filename template {tmpl!r}: unknown field {key!r}'.format(
+                    tmpl=options.raw_ocr_filename_template,
+                    key=ex.args[0],
+                ))
         # It might be tempting to verify language name correctness at argument
         # parse time (rather than after argument parsing). However, it's
         # desirable to be able to specify a language *before* specifying an OCR
@@ -321,6 +331,10 @@ class ArgumentParser(argparse.ArgumentParser):
             options.n_jobs = utils.get_cpu_count()
         elif options.n_jobs < 1:
             options.n_jobs = 1
+        if options.n_jobs > 1 and not ipc.thread_safe:
+            exc = Warning('the subprocess module is not thread-safe')
+            utils.enhance_import_error(exc, 'subprocess32', None, 'https://pypi.python.org/pypi/subprocess32')
+            print('Warning: {exc}'.format(exc=exc), file=sys.stderr)
         return options
 
 class Results(dict):
@@ -352,7 +366,10 @@ class Context(djvu.decode.Context):
     @contextlib.contextmanager
     def get_output_image(self, nth, page_job):
         output_format = self._image_format
-        file = self._temp_file('%06d.%s' % (nth, output_format.extension))
+        file = self._temp_file('{n:06}.{ext}'.format(
+            n=nth,
+            ext=output_format.extension
+        ))
         try:
             output_format.write_image(page_job, self._options.render_layers, file)
             file.flush()
@@ -374,7 +391,7 @@ class Context(djvu.decode.Context):
         result.save(prefix)
 
     def process_page(self, page):
-        logger.info('- Page #%d', page.n + 1)
+        logger.info('- Page #{0}'.format(page.n + 1))
         page_job = page.decode(wait=True)
         # Due to a bug in python-djvulibre <= 0.3.9, sometimes the exception is not raised.
         # Raise in manually in such case.
@@ -384,7 +401,7 @@ class Context(djvu.decode.Context):
         with self.get_output_image(page.n, page_job) as pfile:
             result = self._engine.recognize(pfile, language=self._options.language, details=self._options.details, uax29=self._options.uax29)
             if self._debug:
-                result.save(os.path.join(self._temp_dir, '%06d' % page.n))
+                result.save(os.path.join(self._temp_dir, '{n:06}'.format(n=page.n)))
             self.save_raw_ocr(page, result)
             [text] = self._engine.extract_text(result.as_stringio(),
                 rotation=page.rotation,
@@ -420,7 +437,10 @@ class Context(djvu.decode.Context):
             except Exception as ex:
                 try:
                     interrupted_by_user = isinstance(ex, ipc.CalledProcessInterrupted) and ex.by_user
-                    message = 'Exception while processing page %d:\n%s' % (n + 1, traceback.format_exc())
+                    message = 'Exception while processing page {n}:\n{tb}'.format(
+                        n=(n + 1),
+                        tb=traceback.format_exc()
+                    )
                     logger.error(message.rstrip())
                     if self._options.resume_on_error and not interrupted_by_user:
                         # As requested by user, don't abort on error and pretend that nothing happened.
@@ -441,7 +461,7 @@ class Context(djvu.decode.Context):
 
     def _process(self, path, pages=None):
         self._engine = self._options.engine
-        logger.info('Processing %s:', utils.smart_repr(path, system_encoding))
+        logger.info('Processing {path}:'.format(path=utils.smart_repr(path, system_encoding)))
         document = self.new_document(djvu.decode.FileURI(path))
         document.decoding_job.wait()
         if pages is None:
@@ -471,10 +491,12 @@ class Context(djvu.decode.Context):
                     file_id = page.file.id.encode(system_encoding)
                 except UnicodeError:
                     pageno = page.file.n + 1
-                    logger.warning('warning: cannot convert page %d identifier to locale encoding' % pageno)
-                    sed_file.write('select %d\n' % pageno)
+                    logger.warning('warning: cannot convert page {n} identifier to locale encoding'.format(n=pageno))
+                    sed_file.write('select {n}\n'.format(n=pageno))
                 else:
-                    sed_file.write('select \'%s\'\n' % file_id.replace('\\', '\\\\').replace("'", "\\'"))
+                    sed_file.write("select '{fileid}'\n".format(
+                        fileid=file_id.replace('\\', '\\\\').replace("'", "\\'")
+                    ))
                 sed_file.write('set-txt\n')
                 result = None
                 with condition:
@@ -544,6 +566,6 @@ def main(argv=sys.argv):
     finally:
         temp_dir = context.close()
         if temp_dir is not None:
-            logger.info('Intermediate files were left in the %r directory.' % temp_dir)
+            logger.info('Intermediate files were left in the {path!r} directory.'.format(path=temp_dir))
 
 # vim:ts=4 sts=4 sw=4 et
