@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ def scan(stream, settings):
             stack[-1] += [zone]
         elif element.tag in ('box', 'space'):
             if len(stack) > 3:
-                raise errors.MalformedOcrOutput('<%s> at unexpected depth' % element.tag)
+                raise errors.MalformedOcrOutput('<{tag}> at unexpected depth'.format(tag=element.tag))
             while len(stack) < 3:
                 stack += [[]]
             if element.tag == 'space':
@@ -101,7 +101,7 @@ def scan(stream, settings):
             zone = text_zones.Zone(const.TEXT_ZONE_CHARACTER, bbox, [text])
             stack[-1] += [zone]
         else:
-            raise errors.MalformedOcrOutput('unexpected <%s>' % element.tag.encode('ASCII', 'unicode-escape'))
+            raise errors.MalformedOcrOutput('unexpected <{tag}>'.format(tag=element.tag.encode('ASCII', 'unicode-escape')))
     raise errors.MalformedOcrOutput('<page> not found')
 
 class Engine(common.Engine):
@@ -113,7 +113,6 @@ class Engine(common.Engine):
     extra_args = utils.property([], shlex.split)
 
     def __init__(self, *args, **kwargs):
-        assert args == ()
         common.Engine.__init__(self, *args, **kwargs)
         self._check_version()
 
@@ -170,4 +169,4 @@ class Engine(common.Engine):
         scan_result = scan(stream, settings)
         return [scan_result.sexpr]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
