@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -90,12 +90,12 @@ def scan(stream, settings):
             else:
                 m = _character_re.match(line)
                 if not m:
-                    raise errors.MalformedOcrOutput('bad character description: %r' % line)
+                    raise errors.MalformedOcrOutput('bad character description: {line!r}'.format(line=line))
                 [text] = m.groups()
                 text = text.decode('UTF-8')
             return text_zones.Zone(const.TEXT_ZONE_CHARACTER, bbox, [text])
-        raise errors.MalformedOcrOutput('unexpected line: %r' % line)
-    raise errors.MalformedOcrOutput('unexpected line at EOF: %r' % line)
+        raise errors.MalformedOcrOutput('unexpected line: {line!r}'.format(line=line))
+    raise errors.MalformedOcrOutput('unexpected line at EOF: {line!r}'.format(line=line))
 
 class Engine(common.Engine):
 
@@ -107,7 +107,6 @@ class Engine(common.Engine):
     replacement_character = utils.property(u'\N{REPLACEMENT CHARACTER}', utils.str_as_unicode)
 
     def __init__(self, *args, **kwargs):
-        assert args == ()
         common.Engine.__init__(self, **kwargs)
         try:
             self._languages = self._get_languages()
@@ -127,7 +126,7 @@ class Engine(common.Engine):
             line = ocrad.stderr.read()
             charsets = set(line.split()[1:])
             if 'iso-8859-9' in charsets:
-                result += 'tur',
+                result += ['tur']
         finally:
             try:
                 ocrad.wait()
@@ -172,4 +171,4 @@ class Engine(common.Engine):
         scan_result = scan(stream, settings)
         return [scan_result.sexpr]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
