@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009, 2010, 2011, 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import cgi
 import glob
@@ -42,7 +42,7 @@ _bbox_extras_template = '''\
 <!-- The following script was appended to hOCR by ocrodjvu for internal purposes. -->
 <script type='application/x-ocrodjvu-tesseract'>
 //<![CDATA[
-%s
+{0}
 //]]>
 </script>
 '''
@@ -53,7 +53,7 @@ def _wait_for_worker(worker):
         worker.wait()
     except Exception:
         for line in stderr:
-            sys.stderr.write(line)
+            sys.stderr.write('tesseract: {0}'.format(line))
         raise
     if len(stderr) == 1:
         [line] = stderr
@@ -62,7 +62,7 @@ def _wait_for_worker(worker):
             # if nothing went wrong. Filter out such an unhelpful message.
             return
     for line in stderr:
-        sys.stderr.write(line)
+        sys.stderr.write('tesseract: {0}'.format(line))
 
 def fix_html(s):
     '''
@@ -105,7 +105,6 @@ class Engine(common.Engine):
     fix_html = utils.property(0, int)
 
     def __init__(self, *args, **kwargs):
-        assert args == ()
         common.Engine.__init__(self, **kwargs)
         try:
             self._directory, self._extension = self.get_filesystem_info()
@@ -114,8 +113,8 @@ class Engine(common.Engine):
         if self.use_hocr is None:
             self.use_hocr = self._extension == 'traineddata'
         if self.use_hocr:
-            # Import hocr late, so that importing lxml is not triggered if hOCR
-            # output is not used.
+            # Import hocr late,
+            # so that lxml is imported only when needed.
             from .. import hocr
             self._hocr = hocr
         else:
@@ -147,7 +146,7 @@ class Engine(common.Engine):
                 pass
             else:
                 # This should never happen. Recognizing non-existent image
-                # should always fail. But apparently there are subversion
+                # should always fail. But apparently there are Subversion
                 # snapshots of Tesseract in the wild that do it wrongly. Rather
                 # than failing hard, issue a warning:
                 warnings.warn('unexpected exit code from Tesseract', category=RuntimeWarning, stacklevel=2)
@@ -158,7 +157,8 @@ class Engine(common.Engine):
 
     def _get_languages(self):
         self._user_to_tesseract = {}
-        for filename in glob.iglob(os.path.join(self._directory, '*.%s' % self._extension)):
+        wildcard = '*.{ext}'.format(ext=self._extension)
+        for filename in glob.iglob(os.path.join(self._directory, wildcard)):
             filename = os.path.basename(filename)
             code = os.path.splitext(filename)[0]
             if code == 'osd':
@@ -220,7 +220,7 @@ class Engine(common.Engine):
             with open(tessconf_path, 'wt') as tessconf:
                 # Tesseract 3.00 doesn't come with any config file to enable hOCR
                 # output. Let's create our own one.
-                print >>tessconf, 'tessedit_create_hocr T'
+                print('tessedit_create_hocr T', file=tessconf)
             early_extra_args = []
             late_extra_args = []
             n_early = 0
@@ -257,7 +257,10 @@ class Engine(common.Engine):
                 )
                 _wait_for_worker(worker)
                 with open(os.path.join(output_dir, 'tmp.box'), 'r') as box_file:
-                    contents = contents.replace('</body>', (_bbox_extras_template + '</body>') % box_file.read())
+                    contents = contents.replace(
+                        '</body>',
+                        _bbox_extras_template.format(box_file.read()) + '</body>'
+                    )
         if self.fix_html:
             contents = fix_html(contents)
         return common.Output(
@@ -282,4 +285,4 @@ class Engine(common.Engine):
         zone.rotate(settings.rotation)
         return [zone.sexpr]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
