@@ -17,7 +17,14 @@ import logging
 import os
 import re
 import signal
-import subprocess
+
+thread_safe = True
+try:
+    import subprocess32 as subprocess
+except ImportError:  # <no-coverage>
+    import subprocess
+    if os.name == 'posix':
+        thread_safe = False
 
 # CalledProcessError, CalledProcessInterrupted
 # ============================================
@@ -108,8 +115,8 @@ class Subprocess(subprocess.Popen):
             ex.filename = self.__command
             raise
 
-    def wait(self):
-        return_code = subprocess.Popen.wait(self)
+    def wait(self, *args, **kwargs):
+        return_code = subprocess.Popen.wait(self, *args, **kwargs)
         if return_code > 0:
             raise CalledProcessError(return_code, self.__command)
         if return_code < 0:
@@ -131,6 +138,7 @@ logger = logging.getLogger('ocrodjvu.ipc')
 __all__ = [
     'CalledProcessError', 'CalledProcessInterrupted',
     'Subprocess', 'PIPE',
+    'thread_safe',
 ]
 
 # vim:ts=4 sts=4 sw=4 et
