@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,21 +11,19 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
-
+import io
 import os
 import shlex
 import shutil
 import sys
-from cStringIO import StringIO
 
-from ocrodjvu.cli import djvu2hocr
-from ocrodjvu import temporary
-from ocrodjvu import ipc
+from lib.cli import djvu2hocr
+from lib import temporary
+from lib import ipc
 
 from tests.common import (
     assert_equal,
-    assert_ml_equal,
+    assert_multi_line_equal,
     assert_not_equal,
     interim,
     sorted_glob,
@@ -33,15 +31,11 @@ from tests.common import (
 )
 
 here = os.path.dirname(__file__)
-try:
-    here = os.path.relpath(here)
-except AttributeError:
-    # Python 2.5. No big deal.
-    pass
+here = os.path.relpath(here)
 
 def test_help():
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(djvu2hocr.main, ['', '--help'])
     assert_equal(rc, 0)
@@ -50,8 +44,8 @@ def test_help():
 
 def test_version():
     # https://bugs.debian.org/573496
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(djvu2hocr.main, ['', '--version'])
     assert_equal(rc, 0)
@@ -60,13 +54,13 @@ def test_version():
 
 def _test_from_file(base_filename, index):
     base_filename = os.path.join(here, base_filename)
-    test_filename = '%s.test%d' % (base_filename, index)
+    test_filename = '{base}.test{i}'.format(base=base_filename, i=index)
     djvused_filename = base_filename + '.djvused'
     with open(test_filename, 'rb') as file:
         commandline = file.readline()
         expected_output = file.read()
     args = shlex.split(commandline)
-    assert args[0] == '#'
+    assert_equal(args[0], '#')
     with temporary.directory() as tmpdir:
         djvu_filename = os.path.join(tmpdir, 'empty.djvu')
         args += [djvu_filename]
@@ -93,7 +87,7 @@ def _test_from_file(base_filename, index):
             assert_equal(rc, 0)
             xml_file.seek(0)
             output = xml_file.read()
-    assert_ml_equal(expected_output, output)
+    assert_multi_line_equal(expected_output, output)
 
 def test_from_file():
     for test_filename in sorted_glob(os.path.join(here, '*.test[0-9]')):
@@ -101,4 +95,4 @@ def test_from_file():
         base_filename = os.path.basename(test_filename[:-6])
         yield _test_from_file, base_filename, index
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
