@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,19 +11,20 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
-
 import contextlib
+import io
 import os
+import re
 import shlex
 import sys
-from cStringIO import StringIO
 
-from ocrodjvu.cli import hocr2djvused
+import djvu.sexpr
+
+from lib.cli import hocr2djvused
 
 from tests.common import (
     assert_equal,
-    assert_ml_equal,
+    assert_multi_line_equal,
     assert_not_equal,
     interim,
     sorted_glob,
@@ -31,15 +32,11 @@ from tests.common import (
 )
 
 here = os.path.dirname(__file__)
-try:
-    here = os.path.relpath(here)
-except AttributeError:
-    # Python 2.5. No big deal.
-    pass
+here = os.path.relpath(here)
 
 def test_help():
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(hocr2djvused.main, ['', '--help'])
     assert_equal(rc, 0)
@@ -48,30 +45,40 @@ def test_help():
 
 def test_version():
     # https://bugs.debian.org/573496
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(hocr2djvused.main, ['', '--version'])
     assert_equal(rc, 0)
     assert_not_equal(stderr.getvalue(), '')
     assert_equal(stdout.getvalue(), '')
 
+def normalize_sexpr(match):
+    return djvu.sexpr.Expression.from_string(match.group(1)).as_string(width=80)
+
+_djvused_text_re = re.compile('^([(].*)(?=^[.]$)', flags=(re.MULTILINE | re.DOTALL))
+def normalize_djvused(script):
+    return _djvused_text_re.sub(normalize_sexpr, script)
+
 def _test_from_file(base_filename, index, extra_args):
     base_filename = os.path.join(here, base_filename)
-    test_filename = '%s.test%d' % (base_filename, index)
-    html_filename = '%s.html' % (base_filename,)
+    test_filename = '{base}.test{i}'.format(base=base_filename, i=index)
+    html_filename = '{base}.html'.format(base=base_filename)
     with open(test_filename, 'rb') as file:
         commandline = file.readline()
         expected_output = file.read()
     args = shlex.split(commandline) + shlex.split(extra_args)
-    assert args[0] == '#'
-    with contextlib.closing(StringIO()) as output_file:
+    assert_equal(args[0], '#')
+    with contextlib.closing(io.BytesIO()) as output_file:
         with open(html_filename, 'rb') as html_file:
             with interim(sys, stdin=html_file, stdout=output_file):
                 rc = try_run(hocr2djvused.main, args)
         assert_equal(rc, 0)
         output = output_file.getvalue()
-    assert_ml_equal(expected_output, output)
+    assert_multi_line_equal(
+        normalize_djvused(expected_output),
+        normalize_djvused(output)
+    )
 
 def _rough_test_from_file(base_filename, args):
     args = ['#'] + shlex.split(args)
@@ -79,8 +86,8 @@ def _rough_test_from_file(base_filename, args):
         # Add dummy page-size information
         args += ['--page-size=1000x1000']
     base_filename = os.path.join(here, base_filename)
-    html_filename = '%s.html' % (base_filename,)
-    with contextlib.closing(StringIO()) as output_file:
+    html_filename = '{base}.html'.format(base=base_filename)
+    with contextlib.closing(io.BytesIO()) as output_file:
         with open(html_filename, 'rb') as html_file:
             with interim(sys, stdin=html_file, stdout=output_file):
                 rc = try_run(hocr2djvused.main, args)
@@ -91,7 +98,7 @@ def _rough_test_from_file(base_filename, args):
 def test_from_file():
     rough_test_args = ['--details=lines']
     rough_test_args += [
-        '--details=%s%s' % (details, extra)
+        '--details={0}'.format(details) + extra
         for details in ('words', 'chars')
         for extra in ('', ' --word-segmentation=uax29')
     ]
@@ -103,7 +110,7 @@ def test_from_file():
         for extra_args in '', '--html5':
             yield _test_from_file, base_filename, index, extra_args
     for html_filename in sorted_glob(os.path.join(here, '*.html')):
-        # For HTML files that have no corresponing .test* files, we just check
+        # For HTML files that have no corresponding .test* files, we just check
         # if they won't trigger any exception.
         base_filename = os.path.basename(html_filename[:-5])
         for args in rough_test_args:
@@ -111,4 +118,4 @@ def test_from_file():
                 for extra_args in '', ' --html5':
                     yield _rough_test_from_file, base_filename, args + extra_args
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
