@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,17 +11,15 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
-
+import io
 import sys
-from cStringIO import StringIO
 
-from ocrodjvu.cli import ocrodjvu
+from lib.cli import ocrodjvu
 
 from tests.common import (
     assert_equal,
+    assert_is_not_none,
     assert_not_equal,
-    assert_true,
     interim,
     try_run,
 )
@@ -29,8 +27,8 @@ from tests.common import (
 engines = None
 
 def test_help():
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(ocrodjvu.main, ['', '--help'])
     assert_equal(rc, 0)
@@ -39,8 +37,8 @@ def test_help():
 
 def test_version():
     # https://bugs.debian.org/573496
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(ocrodjvu.main, ['', '--version'])
     assert_equal(rc, 0)
@@ -49,8 +47,8 @@ def test_version():
 
 def test_list_engines():
     global engines
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(ocrodjvu.main, ['', '--list-engines'])
     assert_equal(rc, 0)
@@ -58,8 +56,8 @@ def test_list_engines():
     engines = stdout.getvalue().splitlines()
 
 def _test_list_languages(engine):
-    stdout = StringIO()
-    stderr = StringIO()
+    stdout = io.BytesIO()
+    stderr = io.BytesIO()
     with interim(sys, stdout=stdout, stderr=stderr):
         rc = try_run(ocrodjvu.main, ['', '--engine', engine, '--list-languages'])
     assert_equal(rc, 0)
@@ -67,8 +65,8 @@ def _test_list_languages(engine):
     assert_not_equal(stdout.getvalue(), '')
 
 def test_list_languages():
-    assert_true(engines is not None)
+    assert_is_not_none(engines)
     for engine in engines:
         yield _test_list_languages, engine
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
